# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

ANIMATION_CHOICES = (
    ('bounce', _('Bounce')),
    ('flash', _('Flash')),
    ('pulse', _('Pulse')),
    ('rubberBand', _('Rubber Band')),
    ('shake', _('Shake')),
    ('swing', _('Swing')),
    ('tada', _('Ta-Da')),
    ('wobble', _('Wobble')),
    ('bounceIn', _('Bounce In')),
    ('bounceInDown', _('Bounce In Down')),
    ('bounceInLeft', _('Bounce In Left')),
    ('bounceInRight', _('Bounce In Right')),
    ('bounceInUp', _('Bounce In Up')),
    ('bounceOut', _('Bounce Out')),
    ('bounceOutDown', _('Bounce Out Down')),
    ('bounceOutLeft', _('Bounce Out Left')),
    ('bounceOutRight', _('Bounce Out Right')),
    ('bounceOutUp', _('Bounce Out Up')),
    ('fadeIn', _('Fade In')),
    ('fadeInDown', _('Fade In Down')),
    ('fadeInDownBig', _('Fade In Down Big')),
    ('fadeInLeft', _('Fade In Left')),
    ('fadeInLeftBig', _('Fade In Left Big')),
    ('fadeInRight', _('Fade In Right')),
    ('fadeInRightBig', _('Fade In Right Big')),
    ('fadeInUp', _('Fade In Up')),
    ('fadeInUpBig', _('Fade In Up Big')),
    ('fadeOut', _('Fade Out')),
    ('fadeOutDown', _('Fade Out Down')),
    ('fadeOutDownBig', _('Fade Out Down Big')),
    ('fadeOutLeft', _('Fade Out Left')),
    ('fadeOutLeftBig', _('Fade Out Left Big')),
    ('fadeOutRight', _('Fade Out Right')),
    ('fadeOutRightBig', _('Fade Out Right Big')),
    ('fadeOutUp', _('Fade Out Up')),
    ('fadeOutUpBig', _('Fade Out Up Big')),
    ('flipInX', _('Flip In X')),
    ('flipInY', _('Flip In Y')),
    ('flipOutX', _('Flip Out X')),
    ('flipOutY', _('Flip Out Y')),
    ('lightSpeedIn', _('Light Speed In')),
    ('lightSpeedOut', _('Light Speed Out')),
    ('rotateIn', _('Rotate In')),
    ('rotateInDownLeft', _('Rotate In Down Left')),
    ('rotateInDownRight', _('Rotate In Down Right')),
    ('rotateInUpLeft', _('Rotate In Up Left')),
    ('rotateInUpRight', _('Rotate In Up Right')),
    ('rotateOut', _('Rotate Out')),
    ('rotateOutDownLeft', _('Rotate Out Down Left')),
    ('rotateOutDownRight', _('Rotate Out Down Right')),
    ('rotateOutUpLeft', _('Rotate Out Up Left')),
    ('rotateOutUpRight', _('Rotate Out Up Right')),
    ('hinge', _('Hinge')),
    ('rollIn', _('Roll In')),
    ('rollOut', _('Roll Out')),
    ('zoomIn', _('Zoom In')),
    ('zoomInDown', _('Zoom Out')),
    ('zoomInLeft', _('Zoom In Left')),
    ('zoomInRight', _('Zoom In Right')),
    ('zoomInUp', _('Zoom In Up')),
    ('zoomOut', _('Zoom Out')),
    ('zoomOutDown', _('Zoom Out Down')),
    ('zoomOutLeft', _('Zoom Out Left')),
    ('zoomOutRight', _('Zoom Out Right')),
    ('zoomOutUp', _('Zoom Out Up')),
    ('slideInDown', _('Slide In Down')),
    ('slideInLeft', _('Slide In Left')),
    ('slideInRight', _('Slide In Right')),
    ('slideInUp', _('Slide In Up')),
    ('slideOutDown', _('Slide Out Down')),
    ('slideOutLeft', _('Slide Out Left')),
    ('slideOutRight', _('Slide Out Right')),
    ('slideOutUp', _('Slide Out Up')),
)
